==> JVPC-0.93.zip: JVPC-0.93/vga/Located.java <==
// File: Located.java

package jvpc.vga;

import java.util.*;
import java.io.*;
import kero.util.Assert;

/**
 * Provides information about the location of a VGA-Planets object.
 *
 * <P>Typical subclasses are: marker, explosion, wormhole and Owned.
 * <P>On this level the Delaunay triangulation can be supported.
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     10 VII 1998
 * @version   24 III 2001
 */
public abstract class Located
  extends RstOrTrn
  implements Intersection, Tabulatable
{
  protected int x,y;
  private Vector neighbor; // TODO: Edges for Delaunay trian. (undefined class Edge)

  public Vector getTypes() {
    Vector res = new Vector();
    res.addElement("distance");
    res.addElement("offset");
    res.addElement("location");
    res.addElement("type");
    res.addElement("turn");
    res.addElement("x");
    res.addElement("y");
    return res;
  }

  public Vector getTypeMethods(String typeName) {
    Vector res = new Vector();
    if ("location".equals(typeName)) {
	res.addElement("getPoint");
    } else if ("x".equals(typeName)) {
	res.addElement("getX");
    } else if ("y".equals(typeName)) {
	res.addElement("getY");
    } else if ("distance".equals(typeName)) {
	res.addElement("distance");
    } else if ("offset".equals(typeName)) {
        res.addElement("offset");
    } else if ("type".equals(typeName)) {
	res.addElement("getType");
    } else if ("turn".equals(typeName)) {
	res.addElement("getTurn");
    }
    return res;
  }

    protected Located() {}

    public Located(Universe u) {
	this(u, UNKNOWN, UNKNOWN);
    }

    public Located(Universe u, int x, int y) {
	super(u);
	this.x = x;
	this.y = y;
	if ((x != UNKNOWN) && (y != UNKNOWN)) u.mapsearch.putLocated(this);
    }

  /**
   * @return The X coordinate of this located object.
   */
  public int getX() {
    return x;
  }

  /**
   * @return The Y coordinate of this located object.
   */
  public int getY() {
    return y;
  }

  public MyPoint getPoint() {
    return new MyPoint(x,y);
  }

    public Location getLocation() {
	return universe.getNearestTo(x, y);
    }

    public Location getRstLocation() {
	return getLocation().getRstLocation();
    }

    public void setUniverse(Universe newUniverse) {
	// this suggests there is an old universe, but there is none!
	super.setUniverse(newUniverse);
	if ((x != UNKNOWN) && (y != UNKNOWN)) {
	    universe.mapsearch.putLocated(this);
	}
    }

    public void setX(int newX) {
	Assert.assert((x == UNKNOWN) || (newX == x));
	x = newX;
	if ((x != UNKNOWN) && (y != UNKNOWN)) {
	    universe.mapsearch.putLocated(this);
	}
    }

    public void setY(int newY) {
	Assert.assert((y == UNKNOWN) || (newY == y));
	y = newY;
	if ((x != UNKNOWN) && (y != UNKNOWN)) {
	    universe.mapsearch.putLocated(this);
	}
    }

  public void setPoint(MyPoint p) {
    this.x = p.getXint();
    this.y = p.getYint();
  }

  public int getTurn() {
    return getUniverse().getTurnNumber();
  }

  /**
   * Returns distance to location p
   */
  public double distance(MyPoint p) {
    return p.distance(x, y);
  }

  /**
   * Returns offset to location p
   */
  public MyPoint offset(MyPoint p) {
    return p.sub(x, y);
  }

  /**
   * Returns the type of this object
   */
  public String getType() {
    String name = getClass().getName();
    return name.substring(name.lastIndexOf(".") + 1);
  }

  /**
   * Coordinates (x,y) are fixed, so functions <CODE>setX(int)</code> and
   * <CODE>setY(int)</code> are not available.
   */

  private void addToDelaunay(Located bla) {
    // take ufo of entrance.
    // while (neigbor closer to bla) go closer
    // triangulate triangle t in which bla resides
    // for each edge of t, check whether it needs to be flipped
    // for each flipped edge, do this recursively
  }

  /**
   * Returns true if point p lies on this object
   */
  public boolean liesOn(MyPoint p) {
    return (x == p.getXint()) && (y == p.getYint());
  }

  /**
   * Returns true if point p lies within this object
   */
  public boolean liesWithin(MyPoint p) {
    return (getX() == p.getXint()) && (getY() == p.getYint());
  }

  /**
   * Returns true if line l lies (partly) within this object
   */
  public boolean liesWithin(Line l) {
    return liesOn(l.getFrom()) || liesOn(l.getTo());
  }

  /**
   * Returns true if rectangle r lies (partly) within this object
   */
  public boolean liesWithin(MyRectangle r) {
    return r.liesWithin(new MyPoint(x,y));
  }

  public void assertConsistency() {
    //report("*");
    Location location = universe.getNearestTo(x, y);
    location.assertConsistency();
  }

    public String getString() { return toString(); } // quick hack FIXME
}

==> JVPC-0.94.zip: JVPC-0.94/vga/Located.java <==
// File: Located.java

package jvpc.vga;

import java.util.*;
import java.io.*;
import kero.util.Assert;

/**
 * Provides information about the location of a VGA-Planets object.
 *
 * <P>Typical subclasses are: marker, explosion, wormhole and Owned.
 * <P>On this level the Delaunay triangulation can be supported.
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     10 VII 1998
 * @version   24 III 2001
 */
public abstract class Located
  extends RstOrTrn
  implements Intersection, Tabulatable
{
  protected int x,y;
  private Vector neighbor; // TODO: Edges for Delaunay trian. (undefined class Edge)

  public Vector getTypes() {
    Vector res = new Vector();
    res.addElement("distance");
    res.addElement("offset");
    res.addElement("location");
    res.addElement("type");
    res.addElement("turn");
    res.addElement("x");
    res.addElement("y");
    return res;
  }

  public Vector getTypeMethods(String typeName) {
    Vector res = new Vector();
    if ("location".equals(typeName)) {
	res.addElement("getPoint");
    } else if ("x".equals(typeName)) {
	res.addElement("getX");
    } else if ("y".equals(typeName)) {
	res.addElement("getY");
    } else if ("distance".equals(typeName)) {
	res.addElement("distance");
    } else if ("offset".equals(typeName)) {
        res.addElement("offset");
    } else if ("type".equals(typeName)) {
	res.addElement("getType");
    } else if ("turn".equals(typeName)) {
	res.addElement("getTurn");
    }
    return res;
  }

    protected Located() {}

    public Located(Universe u) {
	this(u, UNKNOWN, UNKNOWN);
    }

    public Located(Universe u, int x, int y) {
	super(u);
	this.x = x;
	this.y = y;
	if ((x != UNKNOWN) && (y != UNKNOWN)) u.mapsearch.putLocated(this);
    }

  /**
   * @return The X coordinate of this located object.
   */
  public int getX() {
    return x;
  }

  /**
   * @return The Y coordinate of this located object.
   */
  public int getY() {
    return y;
  }

  public MyPoint getPoint() {
    return new MyPoint(x,y);
  }

    public Location getLocation() {
	return universe.getNearestTo(x, y);
    }

    public Location getRstLocation() {
	return getLocation().getRstLocation();
    }

    public void setUniverse(Universe newUniverse) {
	// this suggests there is an old universe, but there is none!
	super.setUniverse(newUniverse);
	if ((x != UNKNOWN) && (y != UNKNOWN)) {
	    universe.mapsearch.putLocated(this);
	}
    }

    public void setX(int newX) {
	// Assert.assert((x == UNKNOWN) || (newX == x));
	x = newX;
	if ((x != UNKNOWN) && (y != UNKNOWN)) {
	    universe.mapsearch.putLocated(this);
	}
    }

    public void setY(int newY) {
	// Assert.assert((y == UNKNOWN) || (newY == y));
	y = newY;
	if ((x != UNKNOWN) && (y != UNKNOWN)) {
	    universe.mapsearch.putLocated(this);
	}
    }

  public void setPoint(MyPoint p) {
    this.x = p.getXint();
    this.y = p.getYint();
  }

  public int getTurn() {
    return getUniverse().getTurnNumber();
  }

  /**
   * Returns distance to location p
   */
  public double distance(MyPoint p) {
    return p.distance(x, y);
  }

  /**
   * Returns offset to location p
   */
  public MyPoint offset(MyPoint p) {
    return p.sub(x, y);
  }

  /**
   * Returns the type of this object
   */
  public String getType() {
    String name = getClass().getName();
    return name.substring(name.lastIndexOf(".") + 1);
  }

  /**
   * Coordinates (x,y) are fixed, so functions <CODE>setX(int)</code> and
   * <CODE>setY(int)</code> are not available.
   */

  private void addToDelaunay(Located bla) {
    // take ufo of entrance.
    // while (neigbor closer to bla) go closer
    // triangulate triangle t in which bla resides
    // for each edge of t, check whether it needs to be flipped
    // for each flipped edge, do this recursively
  }

  /**
   * Returns true if point p lies on this object
   */
  public boolean liesOn(MyPoint p) {
    return (x == p.getXint()) && (y == p.getYint());
  }

  /**
   * Returns true if point p lies within this object
   */
  public boolean liesWithin(MyPoint p) {
    return (getX() == p.getXint()) && (getY() == p.getYint());
  }

  /**
   * Returns true if line l lies (partly) within this object
   */
  public boolean liesWithin(Line l) {
    return liesOn(l.getFrom()) || liesOn(l.getTo());
  }

  /**
   * Returns true if rectangle r lies (partly) within this object
   */
  public boolean liesWithin(MyRectangle r) {
    return r.liesWithin(new MyPoint(x,y));
  }

  public void assertConsistency() {
    //report("*");
    Location location = universe.getNearestTo(x, y);
    location.assertConsistency();
  }

    public String getString() { return toString(); } // quick hack FIXME
}
